@@ -42,12 +42,13 @@
     obs <- x$obs
     sim <- x$sim
     r0 <- c(sim, obs)
-    h0 <- hist(sim, plot = FALSE, nclass = nclass, xlim = xlim0)
-    y0 <- max(h0$counts)
     l0 <- max(sim) - min(sim)
     w0 <- l0/(log(length(sim), base = 2) + 1)
     w0 <- w0 * coeff
     xlim0 <- range(r0) + c(-w0, w0)
+    h0 <- hist(sim, plot = FALSE, nclass = nclass)
+    y0 <- max(h0$counts)
+
     hist(sim, plot = TRUE, nclass = nclass, xlim = xlim0, col = grey(0.8), 
         ...)
     lines(c(obs, obs), c(y0/2, 0))
