@@ -21,7 +21,7 @@ void testertracerlq ( int *npermut,
                 double *inersimul);
               
                 
-void matcentragehi (double **tab, double *poili, int *index, int *assign);
+
                 
 void testertracerlq ( int *npermut,
                 double *pcRr, int *npcR,
@@ -307,68 +307,3 @@ void testertracerlq ( int *npermut,
 } /*********************************/
 
  
- void matcentragehi (double **tab, double *poili, int *index, int *assign)
-{
-/*centrage d'un tableau de hill smith
-tab tableau avec quantitatives et qualitatives disjonctifs complets
-poili vecteur poids lignes
-index indique si chaque variables est quali (1) ou quanti (2)
-assign vecteur entier qui donne l'index de la variable pour chaque colonne
-*/
-
-    int l1,c1,i,j,nquant=0,nqual=0,jqual=1,jquant=1;
-    double **tabqual, **tabquant;
-    l1 = tab[0][0];
-    c1 = tab[1][0];
-    for(j=1;j<=c1;j++){
-	if(index[assign[j]]==1){
-		nqual=nqual+1;
-	}
-	else if (index[assign[j]]==2){
-		nquant=nquant+1;
-	}
-    }
-
-    taballoc(&tabqual,l1,nqual);
-    taballoc(&tabquant,l1,nquant);
-
-    for (j=1;j<=c1;j++){
-        if (index[assign[j]]==1) {
-            for (i=1; i<=l1;i++) {
-                tabqual[i][jqual]=tab[i][j];
-		
-                }
-	    jqual=jqual+1;
-        } else if (index[assign[j]]==2){
-            for (i=1; i<=l1;i++) {
-                tabquant[i][jquant]=tab[i][j];
-		
-                }
-	    jquant=jquant+1;
-            }
-     }   
-        
-    
-    matmodifcm (tabqual, poili);
-    matmodifcn (tabquant, poili);
-    jqual=1;
-    jquant=1;
-    
-    for (j=1;j<=c1;j++) {
-	if (index[assign[j]]==1) {
-        	for (i=1;i<=l1;i++) {
-			tab[i][j] = tabqual[i][jqual];
-            	}
-	jqual=jqual+1;	
-        }
-	else if (index[assign[j]]==2) {
-        	for (i=1;i<=l1;i++) {
-			tab[i][j] = tabquant[i][jquant];
-            	}
-	jquant=jquant+1;	
-        }
-    }
-    freetab(tabqual);
-    freetab(tabquant);
-    return;
-}
